@@ -1,5 +1,5 @@
 /* commands/sasl.cpp
-   Copyright (C) 2017-2022 Markus Uhlin. All rights reserved.
+   Copyright (C) 2017-2023 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -43,6 +43,7 @@
 #include "../crypt.h"
 #include "../errHand.h"
 #include "../filePred.h"
+#include "../get_x509_fp.hpp"
 #include "../libUtils.h"
 #include "../main.h"
 #include "../nestHome.h"
@@ -72,6 +73,7 @@ static stringarray_t sasl_cmds = {
 	"pubkey",
 	"mechanism ",
 	"mechanism ecdsa-nist256p-challenge",
+	"mechanism external",
 	"mechanism plain",
 	"mechanism scram-sha-256",
 	"username ",
@@ -80,6 +82,8 @@ static stringarray_t sasl_cmds = {
 	"set ",
 	"set on",
 	"set off",
+	"x509 ",
+	"x509 client.pem",
 };
 
 /*lint -sem(get_filepath, r_null) */
@@ -443,15 +447,47 @@ set_state(char *state)
 	}
 }
 
+static void
+set_x509(const char *filename)
+{
+	static const char err_prefix[] = "fingerprint: ";
+
+	if (!modify_setting("sasl_x509", filename)) {
+		output_message(true, "set x509 failed");
+		return;
+	}
+
+	output_message(false, "set x509 ok");
+	save_to_config();
+
+	try {
+		std::string path("");
+
+		(void) path.append(g_home_dir);
+		(void) path.append(SLASH);
+		(void) path.append(Config("sasl_x509"));
+
+		x509_fingerprint fp(path.c_str());
+
+		fp.show_fp();
+	} catch (const std::runtime_error &e) {
+		printtext_print("err", "%s%s", err_prefix, e.what());
+	} catch (...) {
+		printtext_print("err", "%s%s", err_prefix,
+		    "unknown exception was thrown!");
+	}
+}
+
 /* usage: /sasl <operation> [...]
 
    keygen [--force]
    pubkey
-   mechanism [ecdsa-nist256p-challenge | plain | scram-sha-256]
+   mechanism [ecdsa-nist256p-challenge | external | plain | scram-sha-256]
    username <name>
    password <pass>
    passwd_s <sasl pass> <encryption pass>
-   set [on | off] */
+   set [on | off]
+   x509 <filename> */
 void
 cmd_sasl(const char *data)
 {
@@ -459,6 +495,7 @@ cmd_sasl(const char *data)
 	char username[101] = { '\0' };
 	char password[301] = { '\0' };
 	char state[11] = { '\0' };
+	char filename[51] = { '\0' };
 
 /*
  * sscanf() is safe in this context
@@ -484,6 +521,8 @@ cmd_sasl(const char *data)
 		set_passwd_s(addrof(data[9]));
 	else if (sscanf(data, "set %10s", state) == 1)
 		set_state(state);
+	else if (sscanf(data, "x509 %50s", filename) == 1)
+		set_x509(filename);
 	else
 		output_message(true, "bogus operation");
 
