@@ -1,5 +1,5 @@
 /* User configuration
-   Copyright (C) 2012-2022 Markus Uhlin. All rights reserved.
+   Copyright (C) 2012-2023 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -91,9 +91,11 @@ static struct tagConfDefValues {
 	{ "sasl_mechanism",            TYPE_STRING,  1, "PLAIN" },
 	{ "sasl_username",             TYPE_STRING,  1, "" },
 	{ "sasl_password",             TYPE_STRING,  1, "" },
+	{ "sasl_x509",                 TYPE_STRING,  1, "client.pem" },
 
 	{ "chanserv_host",             TYPE_STRING,  1, "services." },
 	{ "nickserv_host",             TYPE_STRING,  1, "services." },
+	{ "qbot_host",                 TYPE_STRING,  1, "CServe.quakenet.org" },
 
 	{ "account_notify",            TYPE_BOOLEAN, 2, "no" },
 	{ "away_notify",               TYPE_BOOLEAN, 2, "no" },
@@ -113,7 +115,9 @@ static struct tagConfDefValues {
 	{ "beeps",                     TYPE_BOOLEAN, 4, "yes" },
 	{ "cipher_suite",              TYPE_STRING,  3, "compat" },
 	{ "cmd_hist_size",             TYPE_INTEGER, 3, "50" },
+	{ "cmd_type_prot",             TYPE_BOOLEAN, 3, "yes" },
 	{ "connection_timeout",        TYPE_INTEGER, 2, "45" },
+	{ "ctcp_reply",                TYPE_BOOLEAN, 3, "yes" },
 	{ "hostname_checking",         TYPE_BOOLEAN, 2, "yes" },
 	{ "iconv_conversion",          TYPE_BOOLEAN, 2, "no" },
 	{ "joins_parts_quits",         TYPE_BOOLEAN, 2, "no" },
