@@ -1,7 +1,7 @@
 #ifndef COMMAND_HELP_H
 #define COMMAND_HELP_H
 /* commandhelp.h
-   Copyright (C) 2018-2022 Markus Uhlin. All rights reserved.
+   Copyright (C) 2018-2023 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -448,6 +448,15 @@ static usage_t passmod_usage = {
   "",
 };
 
+static usage_t qbot_usage = {
+  N_("usage: /qbot <[service hostname | --]> <command> [...]"),
+  "",
+  N_("Communicate with QuakeNet's network service, the Q bot. If the initial\n"
+     "argument equals to '--', then the value of setting 'qbot_host' is used\n"
+     "as a service hostname."),
+  "",
+};
+
 static usage_t query_usage = {
   N_("usage: /query [nick]"),
   "",
@@ -499,11 +508,12 @@ static usage_t sasl_usage = {
   "",
   "    keygen [--force]",
   "    pubkey",
-  "    mechanism [ecdsa-nist256p-challenge | plain | scram-sha-256]",
+  "    mechanism [ecdsa-nist256p-challenge | external | plain | scram-sha-256]",
   "    username <name>",
   "    password <pass>",
   "    passwd_s <sasl pass> <encryption pass>",
   "    set [on | off]",
+  "    x509 <filename>",
   "",
   N_("SASL is a method that lets you identify with NickServ during the\n"
      "connection process eliminating the need to do it manually."),
@@ -595,6 +605,15 @@ static usage_t squery_usage = {
   "",
 };
 
+static usage_t stats_usage = {
+  N_("usage: /stats [channel]"),
+  "",
+  N_("Outputs a channel's user statistics. If the channel argument is left\n"
+     "empty and the active window is an IRC channel, Swirc will output the\n"
+     "user statistics for that channel."),
+  "",
+};
+
 static usage_t theme_usage = {
   N_("usage: /theme [install <name> | list-remote | set <name>]"),
   "",
