@@ -1,5 +1,5 @@
 /* Input output loop
-   Copyright (C) 2014-2022 Markus Uhlin. All rights reserved.
+   Copyright (C) 2014-2023 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -134,6 +134,7 @@ static struct cmds_tag {
 	{ "p",           cmd_part,        true,  part_usage,        ARRAY_SIZE(part_usage),        true  },
 	{ "part",        cmd_part,        true,  part_usage,        ARRAY_SIZE(part_usage),        true  },
 	{ "passmod",     cmd_passmod,     true,  passmod_usage,     ARRAY_SIZE(passmod_usage),     false },
+	{ "qbot",        cmd_qbot,        true,  qbot_usage,        ARRAY_SIZE(qbot_usage),        true  },
 	{ "query",       cmd_query,       false, query_usage,       ARRAY_SIZE(query_usage),       false },
 	{ "quit",        cmd_quit,        false, quit_usage,        ARRAY_SIZE(quit_usage),        false },
 	{ "resize",      cmd_resize,      false, resize_usage,      ARRAY_SIZE(resize_usage),      false },
@@ -146,6 +147,7 @@ static struct cmds_tag {
 	{ "servlist",    cmd_servlist,    true,  servlist_usage,    ARRAY_SIZE(servlist_usage),    true  },
 	{ "set",         cmd_set,         false, set_usage,         ARRAY_SIZE(set_usage),         false },
 	{ "squery",      cmd_squery,      true,  squery_usage,      ARRAY_SIZE(squery_usage),      true  },
+	{ "stats",       cmd_stats,       true,  stats_usage,       ARRAY_SIZE(stats_usage),       false },
 	{ "theme",       cmd_theme,       false, theme_usage,       ARRAY_SIZE(theme_usage),       false },
 	{ "time",        cmd_time,        true,  time_usage,        ARRAY_SIZE(time_usage),        true  },
 	{ "topic",       cmd_topic,       true,  topic_usage,       ARRAY_SIZE(topic_usage),       false },
@@ -333,8 +335,8 @@ list_all_commands(void)
 
 	sp = &cmds[0];
 	while (sp < &cmds[ARRAY_SIZE(cmds)]) {
-		const char *cmd1 = sp->cmd;
-		char *cmd2, *cmd3;
+		const char	*cmd1 = sp->cmd;
+		char		*cmd2, *cmd3;
 
 		if ((sp + 1) < &cmds[ARRAY_SIZE(cmds)] &&
 		    (sp + 2) < &cmds[ARRAY_SIZE(cmds)]) {
@@ -368,10 +370,10 @@ output_help_for_command(const char *command)
 
 	FOREACH_COMMAND() {
 		if (strings_match(command, sp->cmd)) {
-			const char **lines = & (sp->usage[0]);
-			const size_t size = sp->size;
+			const char**	 lines = &sp->usage[0];
+			const size_t	 size = sp->size;
 
-			while (lines < & (sp->usage[size])) {
+			while (lines < &sp->usage[size]) {
 				if (!strings_match(*lines, ""))
 					printtext(&ctx, "%s", _(*lines));
 				else
@@ -557,8 +559,9 @@ enter_io_loop(void)
 	history = textBuf_new();
 
 	do {
-		char *prompt, *line;
-		static const char cmd_char = '/';
+		char			*prompt, *line;
+		size_t			 len;
+		static const char	 cmd_char = '/';
 
 		prompt = get_prompt();
 		line = readline(prompt);
@@ -578,12 +581,18 @@ enter_io_loop(void)
 			continue;
 		} else if (*line == cmd_char) {
 			handle_cmds(&line[1]);
+		} else if (config_bool("cmd_type_prot", true) &&
+		    g_on_air &&
+		    !strings_match(ACTWINLABEL, g_status_window_label) &&
+		    (len = strspn(line, " ")) <= 5 &&
+		    line[len] == cmd_char) {
+			printtext_print("warn", "Command type protection is "
+			    "%sON%s  --  nothing has been transmitted!",
+			    TXT_BOLD, TXT_BOLD);
 		} else {
-			if (g_on_air && !strings_match(g_active_window->label,
-			    g_status_window_label)) {
-				transmit_user_input(g_active_window->label,
-				    line);
-			}
+			if (g_on_air && !strings_match(ACTWINLABEL,
+			    g_status_window_label))
+				transmit_user_input(ACTWINLABEL, line);
 		}
 
 		add_to_history(line);
@@ -633,8 +642,8 @@ transmit_user_input(const char *winlabel, const char *input)
 		    S1, COLOR1, g_my_nickname, NORMAL, S2,
 		    input);
 	} else {
-		PNAMES n;
-		char c;
+		PNAMES	n;
+		char	c;
 
 		if ((n = event_names_htbl_lookup(g_my_nickname, winlabel)) ==
 		    NULL) {
