@@ -1,5 +1,5 @@
 /* Prints and handles text
-   Copyright (C) 2012-2022 Markus Uhlin. All rights reserved.
+   Copyright (C) 2012-2023 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -300,7 +300,7 @@ case_blink(WINDOW *win, bool *is_blink)
 static void
 case_bold(WINDOW *win, bool *is_bold)
 {
-	if (! (*is_bold)) {
+	if (!*is_bold) {
 		WATTR_ON(win, A_BOLD);
 		*is_bold = true;
 	} else {
@@ -750,7 +750,7 @@ case_default(const struct case_default_context *ctx, int *rep_count,
 static void
 case_reverse(WINDOW *win, bool *is_reverse)
 {
-	if (! (*is_reverse)) {
+	if (!*is_reverse) {
 		WATTR_ON(win, A_REVERSE);
 		*is_reverse = true;
 	} else {
@@ -769,7 +769,7 @@ case_reverse(WINDOW *win, bool *is_reverse)
 static void
 case_underline(WINDOW *win, bool *is_underline)
 {
-	if (! (*is_underline)) {
+	if (!*is_underline) {
 		WATTR_ON(win, A_UNDERLINE);
 		*is_underline = true;
 	} else {
@@ -996,10 +996,10 @@ windows_convert_to_utf8(const char *buf)
 static wchar_t *
 try_convert_buf_with_cs(const char *buf, const char *codeset)
 {
-	struct locale_info *li = NULL;
-	char *original_locale = NULL;
-	char *tmp_locale = NULL;
-	wchar_t *out = NULL;
+	char			*original_locale = NULL;
+	char			*tmp_locale = NULL;
+	struct locale_info	*li = NULL;
+	wchar_t			*out = NULL;
 
 	try {
 		size_t bytes_convert = 0;
@@ -1409,12 +1409,13 @@ void
 printtext_puts(WINDOW *pwin, const char *buf, int indent, int max_lines,
 	       int *rep_count)
 {
-	char *tmpbuf = NULL;
-	const char *tmpbuf_p = NULL;
-	int insert_count = 0;
-	int line_count = 0;
-	struct text_decoration_bools booleans; // calls constructor
-	wchar_t *wc_buf = NULL;
+	char		*tmpbuf = NULL;
+	const char	*tmpbuf_p = NULL;
+	int		 insert_count = 0;
+	int		 line_count = 0;
+	struct text_decoration_bools
+			 booleans; // calls constructor
+	wchar_t		*wc_buf = NULL;
 
 #if defined(UNIX)
 	if ((errno = pthread_once(&puts_init_done, puts_mutex_init)) != 0)
