@@ -1,5 +1,5 @@
 /* Read user input
-   Copyright (C) 2012-2022 Markus Uhlin. All rights reserved.
+   Copyright (C) 2012-2023 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -430,13 +430,16 @@ finalize_out_string(const wchar_t *buf)
 static inline bool
 isInCirculationMode(const TAB_COMPLETION *tc)
 {
-	return (tc->isInCirculationModeForHelp ||
+	return (tc->isInCirculationModeForConnect ||
+	    tc->isInCirculationModeForHelp ||
 	    tc->isInCirculationModeForMsg ||
 	    tc->isInCirculationModeForNotice ||
 	    tc->isInCirculationModeForQuery ||
 	    tc->isInCirculationModeForSasl ||
 	    tc->isInCirculationModeForSettings ||
 	    tc->isInCirculationModeForTheme ||
+	    tc->isInCirculationModeForTime ||
+	    tc->isInCirculationModeForVersion ||
 	    tc->isInCirculationModeForWhois ||
 	    tc->isInCirculationModeForZncCmds ||
 	    tc->isInCirculationModeForCmds ||
